@@ -1,7 +1,7 @@
 /************************************************************************
  * ifchk.c                                                              *
  *                                                                      *
- * Copyright (C) 2002 - 2023 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2024 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous  *
  *                  mode detection and handling.              *
  *                                                            *
- * Version:         1.1.3                                     *
+ * Version:         1.1.4                                     *
  *                                                            *
  * ---------------------------------------------------------- *
  *                                                            *
@@ -264,8 +264,8 @@ int main( int argc, char **argv )
 
     while( i < argc )
     {
-        strncat( argBuf, argv[i], sizeof( argBuf ) );
-        strncat( argBuf, " ", sizeof( argBuf ) );
+        strncat( argBuf, argv[i], sizeof( argBuf ) - strlen( argBuf ) - 1 );
+        strncat( argBuf, " ", sizeof( argBuf ) - strlen( argBuf ) - 1 );
 
         i++;
      }
