@@ -1,7 +1,7 @@
 /************************************************************************
  * linux.c                                                              *
  *                                                                      *
- * Copyright (C) 2002 - 2023 Joshua Birnbaum <engineer@noorg.org>.      *
+ * Copyright (C) 2002 - 2024 Joshua Birnbaum <engineer@noorg.org>.      *
  * All Rights Reserved.                                                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous   *
  *                  mode detection and handling.               *
  *                                                             *
- * Version:         1.1.3                                      *
+ * Version:         1.1.4                                      *
  *                                                             *
  * ----------------------------------------------------------- *
  *                                                             *
@@ -85,6 +85,7 @@ int ifStat( void )
     char slaveBuf[BONDBUFSZ] = "";          /* Buffer for sysfs filesystem binding active slave interface. */
     char *charPtr = NULL;                   /* For actSlave. */
     char *wsPtr = NULL;                     /* Ptr for trailing white space processing. */
+    int wsLen = 0;                          /* For actSlave. */
     int ifCount = 0;                        /* Interface count. */
     struct sysfs_attribute *sysAttr;        /* sysfs attribute to open (e.g., /sys/class/net/eth0/flags). */
     char *endPtr = NULL;                    /* For strtol(). */
@@ -172,8 +173,8 @@ int ifStat( void )
         memset( pathName, '\000', sizeof( pathName ) );
         strncpy( pathName, class -> path, sizeof( pathName ) );
         pathName[SYSFS_PATH_MAX - 1] = '\000';
-        strncat( pathName, "/", ( sizeof( pathName ) - strlen( pathName ) ) - 1 );
-        strncat( pathName, "flags", ( sizeof( pathName ) - strlen( pathName ) ) - 1 );
+        strncat( pathName, "/", sizeof( pathName ) - strlen( pathName ) - 1 );
+        strncat( pathName, "flags", sizeof( pathName ) - strlen( pathName ) - 1 );
 
         /*
          * Handle logical bonding interfaces (e.g., bond0), if present.
@@ -186,8 +187,9 @@ int ifStat( void )
              * Build a full path to the bonding interface slave sysfs file.
              */
             strncpy( slaveFile, "/sys/devices/virtual/net/", sizeof( slaveFile ) );
-            strncat( slaveFile, class -> name, sizeof( slaveFile ) );
-            strncat( slaveFile, "/bonding/slaves", sizeof( slaveFile ) );
+            slaveFile[BONDBUFSZ - 1] = '\000';
+            strncat( slaveFile, class -> name, sizeof( slaveFile ) - strlen( slaveFile) - 1 );
+            strncat( slaveFile, "/bonding/slaves", sizeof( slaveFile ) - strlen( slaveFile ) - 1 );
 
             if( ( slaveData = getSlaves( pathName, class -> name, slaveFile ) ) == NULL )
             {
@@ -195,20 +197,19 @@ int ifStat( void )
                 exit( EXIT_FAILURE );
              }
 
-
             memset( slaves, '\000', sizeof( slaves ) );
             memset( actSlave, '\000', sizeof( actSlave ) );
 
             strncpy( slaves, slaveData, sizeof( slaves ) );
-
             slaves[BONDBUFSZ - 1] = '\000';
 
             wsPtr = strrchr( slaves, ' ' );
             wsPtr++;
 
             charPtr = actSlave;
+            wsLen = strlen( wsPtr );
 
-            memcpy( charPtr, wsPtr, sizeof( wsPtr) );
+            memcpy( charPtr, wsPtr, wsLen );
 
             wsPtr = strrchr( slaves, ' ' );
 
@@ -287,7 +288,6 @@ int ifStat( void )
              }
 
             strncpy( ifr.ifr_name, class -> name, sizeof( ifr.ifr_name ) );
-
             ifr.ifr_name[IFNAMSIZ - 1] = '\000';
 
             if( ioctl( sockfd, SIOCGIFFLAGS, &ifr ) < 0 )
@@ -347,7 +347,6 @@ int ifStat( void )
             /*
              * Create a new node.
              */
-            memset( new, '\000', sizeof( new ) );
             strncpy( new -> data, class -> name, sizeof( new -> data ) );
             new -> data[IFNAMSIZ - 1] = '\000';
             cur = new;
@@ -568,8 +567,8 @@ int ifMetric( struct ifList *list )
         memset( pathName, '\000', sizeof( pathName ) );
         strncpy( pathName, classPath, sizeof( pathName ) );
         pathName[SYSFS_PATH_MAX - 1] = '\000';
-        strncat( pathName, "/", ( sizeof( pathName ) - strlen( pathName ) ) - 1 );
-        strncat( pathName, cur -> data, ( sizeof( pathName ) - strlen( pathName ) ) - 1 );
+        strncat( pathName, "/", sizeof( pathName ) - strlen( pathName ) - 1 );
+        strncat( pathName, cur -> data, sizeof( pathName ) - strlen( pathName ) - 1 );
 
         /*
          * Open the directory.
@@ -612,8 +611,8 @@ int ifMetric( struct ifList *list )
          * reading packets received (rx_packets) and transmitted
          * (tx_packets) on the current interface.
          */
-        strncat( pathName, "/", ( sizeof( pathName ) - strlen( pathName ) ) - 1 );
-        strncat( pathName, "statistics", ( sizeof( pathName ) - strlen( pathName ) ) - 1 );
+        strncat( pathName, "/", sizeof( pathName ) - strlen( pathName ) - 1 );
+        strncat( pathName, "statistics", sizeof( pathName ) - strlen( pathName ) - 1 );
     
         /*
          * Open the statistics directory.
